@@ -116,7 +116,7 @@ def image_add(image_digests):
 @click.argument("digest", nargs=1)
 def image_get(digest):
     """
-    INPUT_IMAGE: Input image can be in the following formats: Image Digest, ImageID or registry/repo:tag
+    INPUT_IMAGE: Input Image Digest (ex. sha256:95c9a61d949bbc622a444202e7faf9529f0dab5773023f173f602151f3a107b3)
     """
     ecode = 0
 
@@ -185,7 +185,7 @@ def list_archived_analyses():
 @click.option("--force", is_flag=True, help="Force deletion of archived analysis")
 def image_delete(digest, force):
     """
-    INPUT_IMAGE: Input image can be in the following formats: Image Digest, ImageID or registry/repo:tag
+    INPUT_IMAGE: Input Image Digest (ex. sha256:95c9a61d949bbc622a444202e7faf9529f0dab5773023f173f602151f3a107b3)
     """
     ecode = 0
 
@@ -241,6 +241,24 @@ def rules():
     is_flag=True,
     help="If true, make this a global rule (admin only)",
 )
+@click.option(
+    "--max-images-per-account",
+    help="Set the maximum number of images per account",
+    type=int,
+)
+@click.option(
+    "--registry-exclude", default="", help="Registry to exclude, wildcard supported"
+)
+@click.option(
+    "--repository-exclude", default="", help="Repository to exclude, wildcard supported"
+)
+@click.option("--tag-exclude", default="", help="Tag to exclude, wildcard supported")
+@click.option(
+    "--exclude-expiration-days",
+    default="-1",
+    help="Days until the exclude block expires",
+    type=int,
+)
 def rule_add(
     days_old,
     tag_versions_newer,
@@ -249,6 +267,11 @@ def rule_add(
     repository_selector,
     tag_selector,
     is_global,
+    max_images_per_account,
+    registry_exclude,
+    repository_exclude,
+    tag_exclude,
+    exclude_expiration_days,
 ):
     """
     Add an analyzed image to the analysis archive
@@ -259,6 +282,13 @@ def rule_add(
 
     archive|delete: the transition to execute - archive or delete. delete transitions occur on already archived analysis, not on the active image analysis
 
+    max_images_per_account: The maximum number of images per account. If specified, no selector should be. Also, it can only be specified on a global rule
+
+    registry_exclude: registries to be excluded
+    repository_exclude: repositories to be excluded
+    tag_exclude: tags to be excluded
+    exclude_expiration_days: Number of days until exclude block expires
+
     """
     ecode = 0
 
@@ -272,6 +302,24 @@ def rule_add(
             ecode = 0
             anchorecli.cli.utils.doexit(ecode)
 
+    if max_images_per_account and not is_global:
+        print("Error: max_images_per_account can only be specified on a global rule")
+        anchorecli.cli.utils.doexit(2)
+
+    if (
+        max_images_per_account
+        and is_selector_default(repository_selector, registry_selector, tag_selector)
+        and is_exclude_default(registry_exclude, repository_exclude, tag_exclude)
+    ):
+        repository_selector = ""
+        registry_selector = ""
+        tag_selector = ""
+    elif max_images_per_account:
+        print(
+            "Error: Selector and exclude cannot be specified along with max_images_per_account"
+        )
+        anchorecli.cli.utils.doexit(2)
+
     try:
         ret = anchorecli.clients.apiexternal.add_transition_rule(
             config,
@@ -282,6 +330,11 @@ def rule_add(
             tag_selector,
             transition,
             is_global,
+            max_images_per_account,
+            registry_exclude,
+            repository_exclude,
+            tag_exclude,
+            exclude_expiration_days,
         )
         ecode = anchorecli.cli.utils.get_ecode(ret)
         if ret["success"]:
@@ -305,6 +358,14 @@ def rule_add(
     anchorecli.cli.utils.doexit(ecode)
 
 
+def is_selector_default(repo, registry, tag):
+    return repo == "*" and registry == "*" and tag == "*"
+
+
+def is_exclude_default(repo, registry, tag):
+    return repo == "" and registry == "" and tag == ""
+
+
 @rules.command(name="get", short_help="Show detail for a specific transition rule")
 @click.argument("rule_id", nargs=1)
 def rule_get(rule_id):
