@@ -2375,6 +2375,11 @@ def add_transition_rule(
     selector_tag="*",
     transition="archive",
     is_global=False,
+    max_images_per_account=None,
+    registry_exclude="",
+    repository_exclude="",
+    tag_exclude="",
+    exclude_expiration_days="-1",
 ):
     """
     POST /archives/rules
@@ -2387,6 +2392,11 @@ def add_transition_rule(
     :param selector_tag: Wild-card supported string to match registry (e.g. 'docker.io', '*', or '*amazonaws.com')
     :param transition: which transition to use, either 'archive' or 'delete'
     :param is_global: should the rule be a global rule (bool)
+    :param max_images_per_account: the maximum number of images per account (must be only
+    :param registry_exclude: registries to exclude from archiving
+    :param repository_exclude:  repositories to exclude from archiving
+    :param tag_exclude: tags to exclude from archiving
+    :param exclude_expiration_days: number of days until exclude expires
     :return:
     """
 
@@ -2411,19 +2421,40 @@ def add_transition_rule(
         raise TypeError("tag_versions_newer must be an integer")
 
     payload = {
-        "selector": {
-            "registry": selector_registry,
-            "repository": selector_repository,
-            "tag": selector_tag,
-        },
         "tag_versions_newer": tag_versions_newer,
         "analysis_age_days": analysis_age_days,
         "transition": transition,
         "system_global": is_global,
     }
 
+    if max_images_per_account:
+        payload.update(
+            {
+                "max_images_per_account": max_images_per_account,
+            }
+        )
+    else:
+        payload.update(
+            {
+                "selector": {
+                    "registry": selector_registry,
+                    "repository": selector_repository,
+                    "tag": selector_tag,
+                },
+                "exclude": {
+                    "expiration_days": exclude_expiration_days,
+                    "selector": {
+                        "registry": registry_exclude,
+                        "repository": repository_exclude,
+                        "tag": tag_exclude,
+                    },
+                },
+            }
+        )
+
     try:
         _logger.debug("POST url=%s", str(url))
+        _logger.debug(json.dumps(payload))
         r = requests.post(
             url,
             data=json.dumps(payload),
@@ -2463,3 +2494,84 @@ def test_webhook(config, webhook_type="general", notification_type="tag_update")
     ret = anchorecli.clients.common.make_client_result(r, raw=False)
 
     return ret
+
+
+def render_url(config, path_parts):
+    base_url = config["url"]
+
+    base_url = re.sub("/$", "", base_url)
+
+    path_parts.insert(0, base_url)
+    return "/".join(path_parts)
+
+
+def enterprise_add_correction(config, correction):
+    user = config["user"]
+    pw = config["pass"]
+
+    url = render_url(config, ["enterprise", "corrections"])
+
+    set_account_header(config)
+
+    _logger.debug("POST url=%s", str(url))
+    r = requests.post(
+        url,
+        auth=(user, pw),
+        verify=config["ssl_verify"],
+        headers=header_overrides,
+        data=json.dumps(correction),
+    )
+    ret = anchorecli.clients.common.make_client_result(r, raw=False)
+
+    return ret
+
+
+def enterprise_get_correction(config, correction_id):
+    user = config["user"]
+    pw = config["pass"]
+
+    url = render_url(config, ["enterprise", "corrections", correction_id])
+
+    set_account_header(config)
+
+    _logger.debug("GET url=%s", str(url))
+    r = requests.get(
+        url, auth=(user, pw), verify=config["ssl_verify"], headers=header_overrides
+    )
+    ret = anchorecli.clients.common.make_client_result(r, raw=False)
+
+    return ret
+
+
+def enterprise_list_corrections(config):
+    user = config["user"]
+    pw = config["pass"]
+
+    url = render_url(config, ["enterprise", "corrections"])
+
+    set_account_header(config)
+
+    _logger.debug("GET url=%s", str(url))
+    r = requests.get(
+        url, auth=(user, pw), verify=config["ssl_verify"], headers=header_overrides
+    )
+    ret = anchorecli.clients.common.make_client_result(r, raw=False)
+
+    return ret
+
+
+def enterprise_delete_correction(config, correction_id):
+    user = config["user"]
+    pw = config["pass"]
+
+    url = render_url(config, ["enterprise", "corrections", correction_id])
+
+    set_account_header(config)
+
+    _logger.debug("DELETE url=%s", str(url))
+    r = requests.delete(
+        url, auth=(user, pw), verify=config["ssl_verify"], headers=header_overrides
+    )
+    ret = anchorecli.clients.common.make_client_result(r, raw=False)
+
+    return ret
